;; Generated package description from embark-consult.el  -*- no-byte-compile: t -*-
(define-package "embark-consult" "1.1" "Consult integration for Embark" '((emacs "27.1") (compat "29.1.4.0") (embark "1.0") (consult "1.0")) :commit "195add1f1ccd1059472c9df7334c97c4d155425e" :authors '(("Omar Antolín Camarena" . "omar@matem.unam.mx")) :maintainer '("Omar Antolín Camarena" . "omar@matem.unam.mx") :keywords '("convenience") :url "https://github.com/oantolin/embark")
